procedure make_sky_em (lambda0in, Rin, lam_winin)

real lambda0in	#in microns
real Rin
real lam_winin	#in Angstroms!!
bool interactive

begin

real 	lambda0, dlambda, R, steplam, steplam0, t, sigma, x
real	w1var, w2var
real	lambda1, lambda2
int	npix, Npix, mycase, numlines, junk, convolve_flag, skip_flag, error_flag

string	emisspec, workspec, emissbox, emissgauss, rebinned, shortspec, high, low, files

# Load required packages
onedspec
language

# Copy input variables:

	R = 		Rin
	lambda0	 = 	lambda0in
	lam_win  = 	lam_winin

# compute wavelength limits in angstroms
	w1var = lambda0*10000 - lam_win/2
	w2var = lambda0*10000 + lam_win/2
# printf("w1var, w2var %f %f\n",w1var, w2var)

workspec = mktemp ("tmp")
emissbox = mktemp ("tmp")
emissgauss = mktemp ("tmp")
rebinned = mktemp ("tmp")
shortspec = mktemp ("tmp")
high = mktemp ("tmp")
low = mktemp ("tmp")

printf("emission:  %s %s %s %s %s \n",workspec, emissbox, emissgauss, shortspec, high, low)

# printf("lambda0 = %f\n",lambda0)

# Select file for transmission and emission

if (0.4<=lambda0&&lambda0<0.90) 
	mycase=1 
else if (0.90<=lambda0&&lambda0<1.13)
	mycase=2
else if (1.13<=lambda0&&lambda0<1.45)
	mycase=3
else if (1.45<=lambda0&&lambda0<1.85)
	mycase=4
else if (1.85<=lambda0&&lambda0<2.56)
	mycase=5
else if (2.56<=lambda0&&lambda0<2.90)
	mycase=6
else if (2.90<=lambda0&&lambda0<4.23)
	mycase=7
else if (4.23<=lambda0&&lambda0<4.60)
	mycase=8
else if (4.60<=lambda0&&lambda0<5.00)
	mycase=9
else
	mycase=10

# printf(" mycase = %d\n",mycase)

convolve_flag = 0		# 1 = proceed to create sky emission table
# skip_flag = 0
error_flag = 0			# 1 = error; do not make emission table; leave routine

steplam0=0.0

switch (mycase) {
	case 1: {
		convolve_flag = 1
		if 	(w1var >= 4000 && w2var <= 6055.103) {
			emisspec = 'atmosdata$sk_40_61cal2.fits'
			if (access ("shortspec"))
				imdelete ("shortspec", verify-)
			scopy(emisspec, shortspec, w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
			steplam0 = 0.034252004
		}

		else if (w1var >= 4000 && w1var<=6055.103 && w2var >=6055.146 && w2var <= 9000){
			# requested range overlaps two source spectra
			# therefore, patch together spectra

			scopy('atmosdata$sk_40_61cal2.fits',low,w1=w1var,w2=6055.103,format="multispec",
				rebin=no, verb-)
			scopy('atmosdata$sk_61_90cal2.fits',high,w1=6055.146,w2=w2var,format="multispec",
				rebin=no, verb-)
			if (access ("shortspec"))
				imdelete ("shortspec", verify-)
			files = high//","//low
			scombine (files,
				shortspec, noutput="", logfile="STDOUT", apertures="", group="apertures",
				combine="sum", reject="none", first=no, w1=w1var, w2=w2var, dw=0.0342520004,
				nw=INDEF,logfile=no,scale="none", zero="none", weight="none", sample="",
				lthreshold=INDEF, hthreshold=INDEF, nlow=1, nhigh=1, nkeep=1, mclip=yes,
				lsigma=3., hsigma=3., rdnoise="0.", gain="1.", snoise="0.", sigscale=0.1,
				pclip=-0.5, grow=0, blank=0.)
			steplam0 = 0.034252004		
		}

		else if (w1var >= 6055.146 && w2var <=9000) {
			emisspec = 'atmosdata$sk_61_90cal2.fits'
			if (access ("shortspec"))
				imdelete ("shortspec", verify-)
			scopy(emisspec, shortspec, w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
			steplam0 = 0.05178870
		}

		else {
			printf("Wavelength range extends beyond tabulated sky \n")
			printf("emission limits from 4000-9000 angstroms.\n")
			error_flag = 1
		} # end of if statements

	}	  # end of case 1
									
	case 2: {
		convolve_flag = 1
		emisspec = 'atmosdata$090_113_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)# Needs emission spectrum
		steplam0 = 5
		
	}
	case 3: {
		convolve_flag = 1
		emisspec = 'atmosdata$J_sky_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 5
		# printf("steplam0= %f\n",steplam0)
		# printf("convolve_flag=%d\n",convolve_flag)	
	}
	case 4: {
		convolve_flag = 1
		emisspec = 'atmosdata$H_sky_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 5
	}
	case 5: {

		convolve_flag = 1
		emisspec = 'atmosdata$K_sky_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("The sky emission used is from Gemini by now. Telescope thermal emission \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")
		steplam0 = 5
	}
	case 6: {
		convolve_flag = 1
		emisspec = 'atmosdata$256_290_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 5
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("Sky emission plus telescope thermal emission \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")
	}
	case 7: {
		convolve_flag = 1
		emisspec = 'atmosdata$290_423_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 5
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("Sky emission plus telescope thermal emission \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")

	}
	case 8: {
		convolve_flag = 1
		emisspec = 'atmosdata$423_460_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 5
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("Sky emission plus telescope thermal emission \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")

	}
	case 9: {
		convolve_flag = 1
		emisspec = 'atmosdata$460_500_em'
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 5
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("Sky emission plus telescope thermal emission \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")
	}
	case 10: {
		printf("Error: lambda0 not in defined bands. \n")
		error_flag = 1
	}
}
# print("Here -1 emission\n")
# printf("steplam0= %f\n",steplam0)

if ((convolve_flag==1) && (error_flag!=1)){

	# Define convolution kernel; steplam in angstroms, lambda0 in microns
	# Note: spectrum data is all in angstroms!!
	
		# desired res. element in Angstroms
		steplam = lambda0*10000/R 
		npix = int(steplam/steplam0)
		x = steplam/steplam0 - int(steplam/steplam0)
		if (x>0.5) npix = npix+1
		# simulation of finite (arbitrary) resolution		
		sigma = 0.5*npix/2.0
	
	# printf("npix,sigma = %f %f\n",npix,sigma)
	# printf("R,steplam = %f %f\n",R,steplam)
	# print("Here 8\n")

	# Copy shortened spectrum to working spectrum
	imcopy (shortspec, workspec, verb-)
#	print here9


	# Convolve with boxcar and gaussian
	boxcar (workspec,
	emissbox, npix, 1, boundary="nearest", constant=0.)
	gauss (emissbox,
	emissgauss, sigma, ratio=1., theta=0., nsigma=4.,  bilinear=no,
	boundary="nearest", constant=0.)
#	print here10

	# Rebin to 3*R
	dispcor (emissgauss,
	   rebinned, linearize=yes, database="database", table="", w1=w1var, w2=w2var,
	   dw=lambda0*10000/(3*R), nw=INDEF, logfile=no, flux=no, samedisp=no, global=no, ignoreaps=no,
	   confirm=no, listonly=no, verbose=no, logfile="")

	# Output final spectrum as IRAF image for diagnostic
	if (access ("test.fits"))
	    imdelete ("test.fits", verify-)
	imcopy(rebinned,"test.fits",verb-)
#	print here11
	
	# Convert spectrum back to table, inverting order
	if (access ("emisstab"))
	    delete ("emisstab", verify-)
	wspectext (rebinned, "emisstab", header=no, wformat="%12.6g")

	head ("emisstab",nlines=1) | scan (lambda1)
	tail ("emisstab",nlines=1) | scan (lambda2)
	if (interactive) {
	    printf("Created atmospheric emission table: \"emisstab\"\n")
	    printf("for lambda = %7.1f to %7.1f angstroms\n",lambda1,lambda2)
	}
	# Set sky table for those cases for which it hasn't already been set

	switch (mycase) { 
	case 1, 3, 4, 5, 6, 7, 8, 9: # These are visible, J, H, K bands
	    sptime.sky = "emisstab"
	}
	# Remove temporary spectra
#	imdel (workspec, verify-)
#	imdel (emissbox, verify-)
#	imdel (emissgauss, verify-)
#	imdel (shortspec, verify-)
#	imdel (high, verify-)
#	imdel (low, verify-)
}
if (convolve_flag == 0) printf("No emission table created.\n")
# printf("end of emission\n")
end
