procedure generic_setup {Rmaxin, slitmaxsecin, Rin, lambdain, slitsecin, npixin}

real    Rmaxin    	{prompt='Maximum resolution R = lambda/(delta lambda)'}
real 	slitmaxsecin	{prompt='Maximum slit size [arcsec]'}
real	Rin		{prompt='Resolution R = lambda/(delta lambda)'}
real	lambdain	{prompt='Central wavelength [microns]'}
real	slitsecin	{prompt='Slit width [arcsec]'}
real	npixin		{prompt='Number of pixels matcheed to slit [real]}

begin

	real Rmax, slitmaxsec, slitsec, delta, deltamax, nu, beta, dpix
	real lambdamic, lambda, slit_mm
        int npix
        
# all internal lengths in meters and all internal angles in radians unless otherwise noted

# Set internal constants:
        dpix = .018e-03 // pixel size
        D = 30.0        // primary diameter
        fnum = 15.0     // focal ratio of telescope/spectrograph (GSMT Cass)
        
# Copy input variables:
	
	Rmax 	= Rmaxin
	R	= Rin
	lambda 	= lambdain*1.0e-06
	slitsec = slitsecin
	delta 	= slitsecin*2*pi/(360*3600) 
 	deltamax = slitmaxsecin*2*pi/(360*3600)
 	npix	= npixin
 	
# Compute collimator focal length
 	fcoll 	= deltamax*fnum*D*Rmax/4
 		
	print('A spectrograph with maximum resolution %f6.0 operating at a maximum practical \n\
	    grating tilt will require a collimator of focal length %f5.3 meters which implies\n\
	    a beam diameter of %f5.3 m\n', Rmax, fcoll, fcoll/fnum)
        
# Evaluate formulae:
	slit_mm = fnum*D*delta*1.0e03
	beta 	= atan(delta*fnum*D*R/(2*fcoll))  # Not required because sptime will caculate it.
	nu 	= 2*sin(beta)/(lambda*1.0e3)      # grating constant in lines/mm
	fcam 	= npix*dpix*cos(beta)*R/(1.0e03*nu*lambda)
	
# Set most of the sptime parameters to default values

<Insert other parameter stuff using mkscript...>
	
specpars.title = 'GENERIC NEAR IR Spectrograph'
specpars.colfl = fcoll
specpars.camfl = fcam
specpars.gmm = nu
sptime(width = +slitsecin)

# Set epar parameters for fcoll, fcam, nu, slit [arcsec], 
#	delete('generic', verify=no)
#	printf('# collimator.fl = %f10.4',fcoll, >>generic)	
#	printf('# camera.fl = %f10.4',fcam, >>generic)
#	printf('# disperser.gmm = %f10.6',nu, >>generic)
#	printf('# width = %f6.3 arcsec',slitsec, >>generic)

#	sptime.spectrographpars = generic	

end
