procedure make_sky_em (lambda0in, Rin, lam_winin)

real lambda0in
real Rin
real lam_winin
bool interactive

begin

real 	lambda0, dlambda, R, steplam, steplam0, t, sigma, x
real	w1var, w2var
real	lambda1, lambda2
int	npix, Npix, mycase, numlines, junk, convolve_flag

string	emisspec, workspec, emissbox, emissgauss, shortspec

# Load required packages
onedspec
language

# Copy input variables:

	R = 		Rin
	lambda0	 = 	lambda0in
	lam_win  = 	lam_winin

# compute wavelength limits in angstroms
	w1var = lambda0*10000 - lam_win/2
	w2var = lambda0*10000 + lam_win/2

# emisspec = mktemp ("tmp")
workspec = mktemp ("tmp")
emissbox = mktemp ("tmp")
emissgauss = mktemp ("tmp")
shortspec = mktemp ("tmp")

# printf("lambda0 = %f\n",lambda0)

# Select file for transmission and emission

if (0.6<=lambda0&&lambda0<0.94) 
	mycase=1 
else if (0.94<=lambda0&&lambda0<1.13)
	mycase=2
else if (1.13<=lambda0&&lambda0<1.45)
	mycase=3
else if (1.45<=lambda0&&lambda0<1.85)
	mycase=4
else if (1.85<=lambda0&&lambda0<2.56)
	mycase=5
else if (2.56<=lambda0&&lambda0<2.90)
	mycase=6
else if (2.90<=lambda0&&lambda0<4.23)
	mycase=7
else if (4.23<=lambda0&&lambda0<4.60)
	mycase=8
else if (4.60<=lambda0&&lambda0<5.00)
	mycase=9
else
	mycase=10

# printf(" mycase = %d\n",mycase)

convolve_flag = 0
steplam0=0.0

switch (mycase) {
	case 1: {
		sptime.sky = 'spectimedb$KPNO/Sky/kpsky'
		printf("Sky emission spectrum set to kpsky (Kitt Peak data)\n")
	}
	case 2: {
		sptime.sky = ""
		# Needs emission spectrum
		printf("Sky emission spectrum not available for this band yet.\n")
	}
	case 3: {
		convolve_flag = 1
		emisspec = 'atmosdata$J_sky_em'
		if (access ("shortspec"))
	   	 	imdelete ("shortspec", verify-)
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 0.3125
		# printf("steplam0= %f\n",steplam0)
		# printf("convolve_flag=%d\n",convolve_flag)
	
	}
	case 4: {
		convolve_flag = 1
		emisspec = 'atmosdata$H_sky_em'
		if (access ("shortspec"))
	   	 	imdelete ("shortspec", verify-)
		scopy(emisspec,shortspec,w1=w1var, w2=w2var, format="multispec", rebin=no, verb-)
		steplam0 = 0.400
	}
	case 5: {
		sptime.sky = ""
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("No sky emission used. Telescope thermal emission \n")
		printf("largely dominates. \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")
	}
	case 6: {
		sptime.sky = ""
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("No sky emission used. Telescope thermal emission \n")
		printf("largely dominates. \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")
	}
	case 7: {
		sptime.sky = ""
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("No sky emission used. Telescope thermal emission \n")
		printf("largely dominates. \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")
	}
	case 8: {
		printf("Error: lambda0 not in defined bands. \n"
	}
	case 9: {
		sptime.sky = ""
		specpars.emissivity = 0.20
		sptime.thermal = 300
		printf("No sky emission used. Telescope thermal emission \n")
		printf("largely dominates. \n")
		printf("Parameters set: T=300; emissivity = 0.2.\n")
	}
	case 10: {
		printf("Error: lambda0 not in defined bands. \n")
	}
}
# print("Here -1 emission\n")
# printf("steplam0= %f\n",steplam0)

if (convolve_flag==1){

	# Define convolution kernel; steplam in angstroms, lambda0 in microns
	# Note: spectrum data is all in angstroms!!
	
		# desired res. element in Angstroms
		steplam = lambda0*10000/R 
		npix = int(steplam/steplam0)
		x = steplam/steplam0 - int(steplam/steplam0)
		if (x>0.5) npix = npix+1
		# simulation of finite (arbitrary) resolution		
		sigma = 0.5*npix/2.0
	
	# printf("npix,sigma = %f %f\n",npix,sigma)
	# printf("R,steplam = %f %f\n",R,steplam)
	# print("Here 2\n")

	# Copy data table to working table
	imcopy (shortspec, workspec, verb-)
		
	# Convolve with boxcar and gaussian
	boxcar (workspec,
	emissbox, npix, 1, boundary="nearest", constant=0.)
	gauss (emissbox,
	emissgauss, sigma, ratio=1., theta=0., nsigma=4.,  bilinear=no,
	boundary="nearest", constant=0.)
	
	# output emission spectrum
	if (access ("emisspec.fits"))
	    imdelete ("emisspec.fits", verify-)
	imcopy(emissgauss,"emisspec.fits",verb-)

	# imdel ("testimage")
	# imcopy (emissgauss, "testimage")
	
	# Convert spectrum back to table, inverting order
	if (access ("emisstab"))
	    delete ("emisstab", verify-)
	wspectext (emissgauss, "emisstab", header=no, wformat="%12.6g")

	head ("emisstab",nlines=1) | scan (lambda1)
	tail ("emisstab",nlines=1) | scan (lambda2)
	
	if (interactive) {
	    printf("Created atmospheric emission table: \"emisstab\"\n")
	    printf("for lambda = %7.1f to %7.1f angstroms\n",lambda1,lambda2)
	}

	# Set sky table for those cases for which it hasn't already been set

	switch (mycase) {
	case 3, 4:
	    sptime.sky = "emisstab"
	}
	
	# Remove temporary spectra
	# imdel (emisspec, verify-)
	imdel (workspec, verify-)
	imdel (emissbox, verify-)
	imdel (emissgauss, verify-)
	imdel (shortspec, verify-)
}
# printf("end of emission\n")

end
