procedure setup (Rmaxin, slitmaxsecin, Rin, lambdain, slitsecin, npixin, set_atm)

real    Rmaxin    	{10000, prompt='Maximum resolution R = lambda/(delta lambda)'}
real 	slitmaxsecin	{0.1, prompt='Maximum slit size [arcsec]'}
real	Rin		{10000, prompt='Resolution R = lambda/(delta lambda)'}
real	lambdain	{1.6, prompt='Central wavelength [microns]'}
real	slitsecin	{0.1, prompt='Slit width [arcsec]'}
real	npixin		{2.0, prompt='Number of pixels matched to slit [real]'}
bool	set_atm		{yes, prompt='Set sky extinction and emission to default values?'}

string	search = "gsmt$GENERIC/"		{prompt="Search path"}
file	telescope = "telescope_GSMT"		{prompt="Telescope file"}
file	detector = "HgCdTe"			{prompt="Detector file"}
bool	interactive = yes			{prompt="Interactive?"}

bool	ans		{prompt=" ", mode="q"}

begin

	real D, fnum, R, Rmax, slitmaxsec, slitsec, delta, deltamax, nu, beta, dpix
	real 	lambdau		# lambda [microns] 
	real	lambda		# lambda [m]
	real	slit_mm 
	real	lam_win		# wavelength range [angstroms]
	real 	fcam, fcoll	# focal lengths [m]
 	real 	pi = 3.141592654
	int 	npix		# number of pixels per slit
	int 	Ndetpix		# number of pixels on detector (from file)
	string 	junk
	bool 	s_atm	
        
# all internal lengths in meters and all internal angles in radians unless otherwise noted

# Set internal constants:
        dpix = .018e-03 # pixel size [m]
        D = 30.0        # primary diameter [m]
        fnum = 15.0     # focal ratio of telescope/spectrograph (GSMT Cass)
        
# Copy input variables:
	
	Rmax 	= Rmaxin
	slitmaxsec = slitmaxsecin
 	deltamax = slitmaxsec*2*pi/(360*3600)
	R	= Rin
	lambdau	= lambdain
	lambda  = lambdau * 1.0e-6  # lambda in m
	slitsec = slitsecin
	delta 	= slitsec*2*pi/(360*3600) 
 	npix	= npixin
	s_atm 	= set_atm
 	
# Compute collimator focal length
 	fcoll 	= deltamax*fnum*D*Rmax/4
 		        
# Evaluate formulae:
	slit_mm = fnum*D*delta*1.0e03
	beta 	= atan2(delta*fnum*D*R/(2*fcoll),1)  # Not required because sptime will calculate it.
	nu 	= 2*sin(beta)/(lambda*1.0e3)      # grating constant in lines/mm
	fcam 	= npix*dpix*cos(beta)*R/(1.0e03*nu*lambda)

# Set some of the sptime parameters to default values
	
	specpars.title = 'GENERIC NEAR IR Spectrograph'

# Use computed parameters to set up spectrograph

	specpars.colfl = fcoll
	specpars.camfl = fcam
	specpars.disptitl = 'Generic grating (Littrow)'
	specpars.disperser = 1.0  # transmission of grating
	specpars.disptyp = 'grating'
	specpars.gmm = nu
	specpars.inoutangle = 0.0   # assures that the spectrograph is operating in Littrow
	specpars.wavelength = lambda*1.0e10  # blaze wavelength
	specpars.block = 'yes'   # assures no contamination from other orders
	specpars.resolution = 0.0 # perfect optics in spectrograph assumed
	sptime.search = search
	sptime.order = 1
	sptime.width = slitsec
	sptime.length = slitsec   # square slit
	sptime.wave = lambda*1.0e6 # observation wavelength output in microns
	sptime.units = "micron"
	sptime.sensfun = 0.0
	sptime.refflux = 20.
	
	printf('\nA spectrograph on a 30m GSMT which achieves a maximum resolution \n\
	of %6.0f operating with a slit width of at most %5.3f arcsec, operating near \n\
	the maximum practical grating tilt, will require a collimator of focal \n\
        length %5.3f m, and a camera of focal length %5.3f m. The beam diameter \n\
	is %5.3f m. The collimator, grating and camera parameters have been set in \n\
	specpars.\n\n',\
	Rmax, slitmaxsec, fcoll, fcam, fcoll/fnum)

	printf('Perfect optics are assumed and higher order diffraction is blocked.\n\n')
	
	printf('This assumes a slit of %5.3f arcsec is matched to %4.1f pixels, \n\
	each of	%4.1f microns.\n\n',slitsec, npix, dpix*1.0e06)

	printf('The camera focal ratio is %6.2f. F-ratios smaller than 1.0 will \n\
	be difficult to achieve.\n\n', fcam*fnum/fcoll)

# Telescope
	specpars.telescope = telescope
	if (interactive) {
	    printf('The telescope parameters are given in the table: %s\n',
		telescope)
	    if (!access (telescope)) {
		printf ("Do you want your own copy of this file?")
		if (ans)
		    copy (search//telescope, ".", verbose+)
	    }
	}

# Detector
	specpars.detector = detector
	if (interactive) {
	    printf('The detector parameters are in the table: %s\n', detector)
	    if (!access (detector)) {
		printf ("Do you want your own copy of this file?")
		if (ans)
		    copy (search//detector, ".", verbose+)
	    }
	}

	if (access (detector))
	    match ("ndisp", detector, stop-, print-, meta+) |
		scan (junk, junk, junk, Ndetpix)
	else
	    match ("ndisp", search//detector, stop-, print-, meta+) |
		scan (junk, junk, junk, Ndetpix)
	
# wavelength window covered by detector at resolution R [angstroms]
	lam_win = Ndetpix*lambdau*10000/(npix*R)

	if(s_atm) {

	make_sky(lambdau,R,lam_win,interactive=interactive)

	}


end
