procedure make_sky_trans (lambda0in, Rin, lam_winin)

real lambda0in
real Rin
real lam_winin
bool interactive

begin

real 	lambda0, dlambda, R, step, step0, t, sigma, x
real	wn1, wn2, delwn, lambda1, lambda2, lam_win
real	wnlo, wnhi
int	npix, Npix, mycase, numlines, junk
string	transfile, file_string
string	workfile, workfile2, workfile3, workfile4###, archivo_trans
string	transim, transbox, transgauss, transang, shortspec
int transflag

# Load required packages
onedspec
language

# Copy input variables:

	lambda0	 = 	lambda0in
	R = 		Rin
	lam_win	=	lam_winin

# compute wavenumber limits in wavenumbers
	wnhi = 1/((lambda0*10000 - lam_win/2)*1.0e-08)
	wnlo = 1/((lambda0*10000 + lam_win/2)*1.0e-08)

#	printf("wnlo,wnhi=%f %f\n",wnlo,wnhi)
if (wnhi<0) wnhi=1e+5 # to avoid that lam_win/2 be bigger than lambda0
#	printf("wnlo,wnhi=%f %f\n",wnlo,wnhi)

transflag = 1 # 1 means transmission; 0 means block	

workfile = mktemp ("tmp")
workfile2 = mktemp ("tmp")
workfile3 = mktemp("tmp")
workfile4 = mktemp("tmp")
transim = mktemp ("tmp")
shortspec = mktemp ("tmp")
transbox = mktemp ("tmp")
transgauss = mktemp ("tmp")
transang = mktemp ("tmp")

# printf("lambda0 = %f\n",lambda0)
# printf("trans: %s %s %s %s %s %s %s %s %s \n",workfile,workfile2,workfile3,workfile4,transim,shortspec,transbox,transgauss,transang)

# Select file for transmission and emission (use 1.4-1.8 micron band for test)
# The data here are tabular data as output from the HITRAN reading program
# HITRANPC

if (0.6<=lambda0&&lambda0<0.94) 
	mycase=1 
else if (0.94<=lambda0&&lambda0<1.13)
	mycase=2
else if (1.13<=lambda0&&lambda0<1.45)
	mycase=3
else if (1.45<=lambda0&&lambda0<1.85)
	mycase=4
else if (1.85<=lambda0&&lambda0<2.56)
	mycase=5
else if (2.56<=lambda0&&lambda0<2.90)
	mycase=6
	#very poor transmission
else if (2.90<=lambda0&&lambda0<4.23)
	mycase=7
else if (4.23<=lambda0&&lambda0<4.60)
	mycase=8
	#very poor transmission
else if (4.60<=lambda0&&lambda0<5.00)
	mycase=9
else if (0.40<=lambda0&&lambda0<0.60)
	mycase=10
else
	mycase=11

#printf(" trans:mycase = %d\n",mycase)

switch (mycase) {
	case 1: {
		transfile = "atmosdata$0.6_0.94u.hdf"
		step0 = 0.6828
	}
	case 2: {
		transfile = "atmosdata$0.9_1.2u.hdf"
		step0 = 0.2431
	}
	case 3: {
		transfile = 'atmosdata$1.13_1.45u.hdf'
		step0 = 0.3952
	}
	case 4: {
		transfile = 'atmosdata$1.45_1.85u.hdf'
		step0 = 0.3078
	}
	case 5: {
		transfile = 'atmosdata$1.85_2.56u.hdf'
		step0 = 0.233
	}
	case 6: {
                printf("No useful transmission.Set to zero. \n")
		transflag = 0
	}
	case 7: {
		transfile = 'atmosdata$2.8_4.3u.hdf'
		step0 = 0.0505
	}
	case 8: {
                printf("No useful transmission. Set to zero. \n")
		transflag = 0
	}
	case 9: {
		transfile = 'atmosdata$4.5_5.5u.hdf'
		step0 = 0.0505
	}
	case 10: {
		transfile = 'atmosdata$0.4_0.6u.hdf'
		step0 = 0.5208
	}
	case 11: {
		printf("Error: lambda0 not in defined bands. \n")
		printf("Transmission curves not available.\n")
		printf("Transmission set artificially to 0.0.\n")
		transflag = 0;
	}
}

if(transflag == 1){

	# Define convolution kernel; step in wavenumbers, lambda in microns


	dlambda = lambda0/R
	step = dlambda*1.0e04/(lambda0*lambda0)
	npix = int(step/step0)
	x = step/step0 - int(step/step0)
	if (x>0.5) npix = npix+1
	sigma = 0.5*npix/2.0

	# printf("npix,sigma = %f %f\n",npix,sigma)
	# printf("R,step = %f %f\n",R,step)

	# Copy data table to working table
	copy (transfile, workfile)
	# print("Here 0\n")

	# Eliminate column1 of Hitran output data
	fields (workfile,
		"2,3", lines="9-", quit_if_miss=no, print_file_n=no, >workfile2)
	count(workfile2) | scan(numlines)
	head (workfile2,nlines=1) | scan (wn1)
	tail (workfile2,nlines=1) | scan (wn2)

	delwn = (wn2-wn1)/(numlines-1)


	# printf("wn1,wn2=%f %f\n",wn1,wn2)

	# print("Here 1 trans\n") 


	# Convert from table to spectrum (IRAF image)
	rspectext (workfile2,
	transim, title="test", flux=no, dtype="linear", crval1=wn1, cdelt1=delwn,
		fd1="", fd2="")
	# print("Here 2\n")

	# Insert wavenumbers as frequency unit
	hedit (transim,
		"WAT1_001", 'wtype=linear label="Wave number" units=wn', add=yes, 
		delete=no,verify-, show-, update=yes)
	# print("Here 3\n")


	# printf("wnlo, wnhi, shortspec = %f %f %s\n", wnlo, wnhi, shortspec)

	# select subspectrum here
	scopy(transim, shortspec, w1=wnlo, w2=wnhi, format="multispec", rebin=no, 
		clob+, verb-)
	# print("Here 4\n")
	# imcopy (shortspec, "testim.imh")

	hselect (shortspec, "naxis1", yes) | scan (Npix)

	# Get number of lines, wavenumber scale data

	lambda1 = 1.0e08/wnhi
	lambda2 = 1.0e08/wnlo


	# Convolve with boxcar and gaussian
	boxcar (shortspec, transbox, npix, 1, boundary="nearest", constant=0.)
	# print("Here 5\n")

	gauss (transbox,transgauss, sigma, ratio=1., theta=0., nsigma=4.,  
		bilinear=no,boundary="nearest", constant=0.)
	# print("Here 6\n")
	# imdel ("testimage")
	# imcopy (transgauss, "testimage")

	# convert wavenumbers to angstroms
	disptrans (transgauss, transang, "angstroms", error=0.01, linearize=no, 
		verbose=no, air="none", t=15., p=760., f=4.)
	# print("Here 7\n")

#-------------
	# created 29 April 2003
	# the string "archivo_trans" was declarated in the begin.
	#if (access ("pre_transmission.imh")) imdelete ("pre_transmission.imh", verify-)	
	#imcopy (transang, "pre_transmission")

	#Convert spectrum back to table, inverting order
	#printf("%s[%d:1]\n", transang, Npix) | scan(archivo_trans)
	#printf("Npix=%f\n",Npix)
	#if (access ("transmission")) delete ("transmission", verify-)
	#wspectext (archivo_trans, "transmission", header=no, wformat="%12.4f")
#-------------


	# convert transmission to extinction/airmass

	sarith(transang, op="log", output=workfile3)
	sarith(workfile3, "*", -2.5, workfile4)
	# printf("version extinct\n")

	# Convert spectrum back to table, inverting order
	printf("%s[%d:1]\n", workfile4, Npix) | scan(file_string)
	# print("Here 8\n")
	# printf("%s\n",file_string)

	if (access ("transtab"))
    		delete ("transtab", verify-)
	wspectext (file_string, "transtab", header=no, wformat="%12.4f")
	if (interactive) {
    		printf("Created atmospheric transmission table: \"transtab\"\n")
    		printf("for lambda = %7.1f to %7.1f angstroms\n",lambda1,lambda2)
	}

	sptime.extinction = "transtab"

#	 printf ("here trans\n")	

}else{

	sptime.extinction = 'block'
}

# Remove temporary files.
delete (workfile, verify-)
delete (workfile2, verify-)
imdel (workfile3, verify-)
imdel (workfile4, verify-)
imdel (transim, verify-)
imdel (shortspec, verify-)
imdel (transbox, verify-)
imdel (transgauss, verify-)
imdel (transang, verify-)
# printf("end of trans\n")
end

