#This copy brought from tucana 14May02 for modification
procedure setup (telsizein,Rmaxin, slitmaxsecin, Rin, lambdain, slitsecin, npixin, set_atm)

real	telsizein	{30, prompt='Telescope diameter [m]'}
real    Rmaxin    	{10000, prompt='Maximum resolution R = lambda/(delta lambda)'}
real 	slitmaxsecin	{0.1, prompt='Maximum slit size [arcsec]'}
real	Rin		{1000, prompt='Resolution R = lambda/(delta lambda)'}
real	lambdain	{1.6, prompt='Central wavelength [microns]'}
real	slitsecin	{0.1, prompt='Slit width [arcsec]'}
real	npixin		{2.0, prompt='Number of pixels matched to slit [real]'}
bool	set_atm		{yes, prompt='Set sky extinction and emission to default values?'}

string	search = "gsmt$GENERIC/"		{prompt="Search path"}
file	telescope = "telescope_GSMT"		{prompt="Telescope file"}
file	detector = "HgCdTe_gen"			{prompt="Detector file"}
bool	interactive = yes			{prompt="Interactive?"}

bool	ans	                        {prompt=" ", mode="q"}

begin
	real 	telsize, D, tel_area, tel_scale, fnum, R, Rmax, slitmaxsec, slitsec, delta, deltamax, nu, beta, dpix
	real 	lambdau		# lambda [microns] 
	real	lambda		# lambda [m]
	real	slit_mm 
	real	lam_win		# wavelength range [angstroms]
	real 	fcam, fcoll	# focal lengths [m]
 	real 	pi = 3.141592654
	int 	npix		# number of pixels per slit
	int 	Ndetpix		# number of pixels on detector (read from detector file)
	string 	junk
	bool 	s_atm	

# all internal lengths in meters and all internal angles in radians unless otherwise noted

        
# Copy input variables:	
	telsize = telsizein
	Rmax 	= Rmaxin # maximum possible resolution with spectrograph
	slitmaxsec = slitmaxsecin
 	deltamax = slitmaxsec*2*pi/(360*3600)
	R	= Rin # resolution
	lambdau	= lambdain
	lambda  = lambdau * 1.0e-6  # lambda in m
	slitsec = slitsecin
	delta 	= slitsec*2*pi/(360*3600) 
 	npix	= npixin
	s_atm 	= set_atm


# Detector
	if (lambdau > 1.0) {
		detector = "HgCdTe_gen" 
	} else {
		detector = "CCD_gen" 
	}
	specpars.detector = detector
	if (interactive) {
	    printf('The detector parameters are in the table: %s\n', detector)
	    if (!access (detector)) {
		printf ("Do you want your own copy of this file?")
		ans = no
		if (ans)
		    copy (search//detector, ".", verbose+)
	    }
	}

	if (access (detector))
	    match ("ndisp", detector, stop-, print-, meta+) |
		scan (junk, junk, junk, Ndetpix)
	else
	    match ("ndisp", search//detector, stop-, print-, meta+) |
		scan (junk, junk, junk, Ndetpix)

	if (access (detector))
	    match ("pixsize", detector, stop-, print-, meta+) |
		scan (junk, junk, junk, dpix)
	else
	    match ("pixsize", search//detector, stop-, print-, meta+) |
		scan (junk, junk, junk, dpix)
	dpix = dpix*1.0e-03 # set pixel size in meters






# Set internal constants:
#       dpix 	= .018e-03 # pixel size for typical detector [m]
        D 	= telsize  # primary diameter [m] no longer a constant!
        fnum 	= 18.75    # focal ratio of telescope/spectrograph (GSMT Cass)
 	
# Compute collimator focal length
 	fcoll 	= deltamax*fnum*D*Rmax/4
 		        
# Evaluate formulae:
	slit_mm = fnum*D*delta*1.0e03
	beta 	= atan2(delta*fnum*D*R/(2*fcoll),1)  # Not required because sptime will calculate it.
	nu 	= 2*sin(beta)/(lambda*1.0e3)      # grating constant in lines/mm
	fcam 	= npix*dpix*cos(beta)*R/(1.0e03*nu*lambda)

# Set some of the sptime parameters to default values	
	specpars.title = 'GENERIC NEAR IR Spectrograph'

# Use computed parameters to set up spectrograph
	specpars.colfl = fcoll
	specpars.camfl = fcam
	specpars.disptitl = 'Generic grating (Littrow)'
	specpars.disperser = 1.0  # transmission of grating
	specpars.disptyp = 'grating'
	specpars.gmm = nu
	specpars.inoutangle = 0.0   # assures that the spectrograph is operating in Littrow
	specpars.wavelength = lambda*1.0e10  # blaze wavelength
	specpars.block = 'yes'   # assures no contamination from other orders
	specpars.resolution = 0.0 # perfect optics in spectrograph assumed
	sptime.search = search
	sptime.order = 1
	sptime.width = slitsec
	sptime.length = -10      # fixed 10 pixel slit for bknd subtraction
	sptime.wave = lambda*1.0e6 # observation wavelength output in microns
	sptime.units = "micron"
	sptime.sensfun = 0.0
#	sptime.refflux = 20.
	sptime.nw = 513. # full resolution in graphic output 
	
	printf('\nA spectrograph on a %3.0f m GSMT which achieves a maximum resolution \n\
	of %6.0f operating with a slit width of at most %5.3f arcsec, operating near \n\
	the maximum practical grating tilt, will require a collimator of focal \n\
        length %5.3f m, and a camera of focal length %5.3f m. The beam diameter \n\
	is %5.3f m. The collimator, grating and camera parameters have been set in \n\
	specpars.\n\n',\
	D, Rmax, slitmaxsec, fcoll, fcam, fcoll/fnum)

	printf('Perfect optics are assumed and higher order diffraction is blocked.\n\n')
	
	
	printf('This assumes a slit of %5.3f arcsec is matched to %4.1f pixels, \n\
	each of	%4.1f microns.\n\n',slitsec, npix, dpix*1.0e06)

	printf('The camera focal ratio is %6.2f. F-ratios smaller than 1.0 will \n\
	be difficult to achieve.\n\n', fcam*fnum/fcoll)

# Telescope
# Use telsize to compute area (using 5% obscuration) and scale
	tel_area =  pi*(D*D/4)*0.95
	tel_scale = 1.0e-3*360*3600/(2*pi*fnum*D) # arcsec/mm
	if (access("telescope_generic")) delete telescope_generic 

# make telescope file
	if (telsize != 30.0) {
		if (!access("telescope_generic")) {
			printf('A new temporary telescope file "telescope_generic" has been created using \n\
                        a diameter of %3.1f m.\n',telsize) 
			printf('# title = "Generic Telescope" \n',         >"telescope_generic")
  			printf("# area = %8.3f [m^2]\n",tel_area,         >>"telescope_generic")
			printf('# scale = %5.3f [arcsec/mm]\n',tel_scale, >>"telescope_generic")
			printf('# emissivity = 0.1\n',                    >>"telescope_generic")
		}
		specpars.telescope = "telescope_generic"
	}else{
	   telescope = "telescope_GSMT"
	   specpars.telescope = telescope
	   if (interactive) {
	       printf('The telescope parameters are given in the table: %s\n',
		   telescope)
	       if (!access (telescope)) {
		   printf ("Do you want your own copy of this file?")
		   if (ans)
		       copy (search//telescope, ".", verbose+)
	       }
	   }
	}

	
# wavelength window covered by detector at resolution R [angstroms]
	lam_win = Ndetpix*lambdau*10000/(npix*R)

	if(s_atm) {

	make_sky(lambdau,R,lam_win,interactive=interactive)

	}

end
