procedure make_sky_trans (lambda0in, Rin)

real lambda0in
real Rin

begin

real 	lambda0, dlambda, R, step, step0, t, sigma, x
real	wn1, wn2, delwn, lambda1, lambda2
int	npix, Npix, mycase, numlines, junk
string	transfile, file_string
string	workfile, workfile2, transim, transbox, transgauss, transang

# Load required packages
onedspec
language

# Copy input variables:

	lambda0	 = 	lambda0in
	R = 		Rin

workfile = mktemp ("tmp")
workfile2 = mktemp ("tmp")
transim = mktemp ("tmp")
transbox = mktemp ("tmp")
transgauss = mktemp ("tmp")
transang = mktemp ("tmp")

# printf("lambda0 = %f\n",lambda0)

# Select file for transmission and emission (use 1.4-1.8 micron band for test)

if (0.6<=lambda0&&lambda0<0.94) 
	mycase=1 
else if (0.94<=lambda0&&lambda0<1.13)
	mycase=2
else if (1.13<=lambda0&&lambda0<1.45)
	mycase=3
else if (1.45<=lambda0&&lambda0<1.85)
	mycase=4
else if (1.85<=lambda0&&lambda0<2.56)
	mycase=5
else if (2.56<=lambda0&&lambda0<2.90)
	mycase=6
else if (2.90<=lambda0&&lambda0<4.23)
	mycase=7
else if (4.23<=lambda0&&lambda0<4.60)
	mycase=8
else if (4.60<=lambda0&&lambda0<5.00)
	mycase=9
else
	mycase=10

# printf(" mycase = %d\n",mycase)

switch (mycase) {
	case 1: {
		transfile = "src$0.6_0.9u.hdf"
		step0 = 0.3472
	}
	case 2: {
		transfile = "src$0.9_1.2u.hdf"
		step0 = 0.2431
	}
	case 3: {
		transfile = 'src$1.1_1.4u.hdf'
		step0 = 0.2029
	}
	case 4: {
		transfile = 'src$1.4_1.8u.hdf'
		step0 = 0.1587
	}
	case 5: {
		transfile = 'src$1.9_2.6u.hdf'
		step0 = 0.1139
	}
	case 6: {
		transfile = 'src$2.8_4.3u.hdf'
		step0 = 0.0737
	}
	case 7: {
		transfile = 'src$4.5_5.5u.hdf'
		step0 = 0.0505
	}
	case 8: {
		printf("Error: lambda0 not in defined bands. \n"
	}
	case 9: {
		transfile = 'src$4.5_5.5u.hdf'
		step0 = 0.0505
	}
	case 10: {
		printf("Error: lambda0 not in defined bands. \n")
	}
}

# Define convolution kernel; step in wavenumbers, lambda in microns


	dlambda = lambda0/R
	step = dlambda*1.0e04/(lambda0*lambda0)
	npix = int(step/step0)
	x = step/step0 - int(step/step0)
	if (x>0.5) npix = npix+1
	sigma = 0.5*npix/2.0

# printf("npix,sigma = %f %f\n",npix,sigma)
# printf("R,step = %f %f\n",R,step)

# Copy data table to working table
copy (transfile, workfile)
# print("Here 0\n")

# Eliminate column1 of Hitran output data
fields (workfile,
"2,3", lines="9-", quit_if_miss=no, print_file_n=no, >workfile2)
# print("Here 1\n") 

# Get number of lines, wavenumber scale data

count(workfile2) | scan(numlines)
head (workfile2,nlines=1) | scan (wn1)
tail (workfile2,nlines=1) | scan (wn2)

delwn = (wn2-wn1)/(numlines-1)

lambda1 = 1.0e08/wn2
lambda2 = 1.0e08/wn1

# Convert from table to spectrum (IRAF image)
rspectext (workfile2,
transim, title="test", flux=no, dtype="linear", crval1=wn1, cdelt1=delwn,
fd1="", fd2="")
# print("Here 2\n")

# Insert wavenumbers as frequency unit
hedit (transim,
"WAT1_001", 'wtype=linear label="Wave number" units=wn', add=yes, delete=no,
verify-, show-, update=yes)
# print("Here 3\n")

hselect (transim, "naxis1", yes) | scan (Npix)
# print("Here 4\n")

# Convolve with boxcar and gaussian
boxcar (transim,
transbox, npix, 1, boundary="nearest", constant=0.)
# print("Here 5\n")

gauss (transbox,
transgauss, sigma, ratio=1., theta=0., nsigma=4.,  bilinear=no,
boundary="nearest", constant=0.)
# print("Here 6\n")
# imdel ("testimage")
# imcopy (transgauss, "testimage")

# convert wavenumbers to angstroms
disptrans (transgauss,
transang, "angstroms", error=0.01, linearize=no, verbose=no, air="none",
t=15., p=760., f=4.)
# print("Here 7\n")

# Convert spectrum back to table, inverting order
printf("%s[%d:1]\n", transang, Npix) | scan(file_string)
# print("Here 8\n")
# printf("%s\n",file_string)

if (access ("transtab"))
    delete ("transtab", verify-)
wspectext (file_string, "transtab", header=no, wformat="%12.4f")
printf("Created atmospheric transmission table: \"transtab\"\n")
printf("for lambda = %7.1f to %7.1f angstroms\n",lambda1,lambda2)

sptime.extinction = "transtab"

# Remove temporary files.
delete (workfile, verify-)
delete (workfile2, verify-)
imdel (transim, verify-)
imdel (transbox, verify-)
imdel (transgauss, verify-)
imdel (transang, verify-)

end
