# SPTEMPLATE -- Make a template spectrum for SPTIME.


procedure sptemplate (input, template, redshift, mag)

file	input			{prompt="Input spectrum"}
file	template		{prompt="Output spectrum template"}
real	redshift = 0		{prompt="Redshift"}
real	mag = 0			{prompt="Magnitude"}

real	w1 = 3000		{prompt="Starting wavelength"}
real	w2 = 11000		{prompt="Ending wavelength"}
string	band = "V"		{prompt="Bandpass"}
string	tmpltdir = "sptemplates$"	{prompt="Template directory"}

begin
	file	in, out, temp1, temp2
	real	z, z1, m, fvega, fgal
	string	dummy
	struct	title

	in = input
	if (imaccess(tmpltdir//in) == NO) {
	    sptime.spectrum = in
	    return
	}

	out = template
	z = redshift
	m = mag
	temp1 = mktemp ("spt")
	temp2 = mktemp ("spt")

	z1 = 1/(1+z) - 1

	dopcor (tmpltdir//in, temp1, z1, isvelocity-, add-, dispersion+, flux-,
	    apertures="", verbose-)

	scopy (temp1, out, w1=w1, w2=w2, apertures="", bands="", beams="",
	    apmodulus=0, format="multispec", renumber-, offset=0,
	    clobber-, merge-, rebin-, verbose=no)

	imdelete (temp1, verify-)

	sbands (tmpltdir//"Vega", "STDOUT", tmpltdir//band, apertures="",
	    normalize+, mag-, magzero=0., verbose-) |
	    scan (dummy, dummy, fvega)
	sbands (out, "STDOUT", tmpltdir//band, apertures="", normalize+, mag-,
	    magzero=0., verbose-) |
	    scan (dummy, dummy, fgal)
	fgal = 10. ** (-0.4 * m) * fvega / fgal
	imrename (out, temp1)
	imarith (temp1, "*", fgal, temp2)
	imdel (temp1, verify-)

	hselect (temp2, "title", yes) | scan (title)
	printf ("# title = '%s:  z = %.3g, %s = %.1f'\n\n",
	    title, z, band, m, > out)

	wspectext (temp2, temp1, header=no, wformat="")
	type (temp1, >> out)

	imdel (temp2, verify-)
	delete (temp1, verify-)
end
