procedure generic_setup (Rmaxin, slitmaxsecin, Rin, lambdain, slitsecin, npixin, set_atm)

real    Rmaxin    	{prompt='Maximum resolution R = lambda/(delta lambda)'}
real 	slitmaxsecin	{prompt='Maximum slit size [arcsec]'}
real	Rin		{prompt='Resolution R = lambda/(delta lambda)'}
real	lambdain	{prompt='Central wavelength [microns]'}
real	slitsecin	{prompt='Slit width [arcsec]'}
real	npixin		{prompt='Number of pixels matched to slit [real]'}
bool	set_atm		{prompt='Set sky extinction and emission to default values?'}

begin

	real D, fnum, R, Rmax, slitmaxsec, slitsec, delta, deltamax, nu, beta, dpix
	real lambdau, lambda, slit_mm
	real fcam, fcoll
 	real pi = 3.141592654
	int npix
	bool s_atm	
        
# all internal lengths in meters and all internal angles in radians unless otherwise noted

# Set internal constants:
        dpix = .018e-03 # pixel size [m]
        D = 30.0        # primary diameter [m]
        fnum = 15.0     # focal ratio of telescope/spectrograph (GSMT Cass)
        
# Copy input variables:
	
	Rmax 	= Rmaxin
	slitmaxsec = slitmaxsecin
 	deltamax = slitmaxsec*2*pi/(360*3600)
	R	= Rin
	lambdau	= lambdain
	lambda  = lambdau * 1.0e-6
	slitsec = slitsecin
	delta 	= slitsec*2*pi/(360*3600) 
 	npix	= npixin
	s_atm 	= set_atm
 	
# Compute collimator focal length
 	fcoll 	= deltamax*fnum*D*Rmax/4
 		        
# Evaluate formulae:
	slit_mm = fnum*D*delta*1.0e03
	beta 	= atan2(delta*fnum*D*R/(2*fcoll),1)  # Not required because sptime will caculate it.
	nu 	= 2*sin(beta)/(lambda*1.0e3)      # grating constant in lines/mm
	fcam 	= npix*dpix*cos(beta)*R/(1.0e03*nu*lambda)

# Set some of the sptime parameters to default values
	
	specpars.title = 'GENERIC NEAR IR Spectrograph'

# Use computed parameters to set up spectrograph

	specpars.colfl = fcoll
	specpars.camfl = fcam
	specpars.disptitl = 'Generic grating (Littrow)'
	specpars.disperser = 1.0  # transmission of grating
	specpars.disptyp = 'grating'
	specpars.gmm = nu
	specpars.inoutangle = 0.0   # assures that the spectrograph is operating in Littrow
	specpars.wavelength = lambda*1.0e10  # blaze wavelength

	sptime.order = 1
	sptime.width = slitsec
	sptime.wave = lambda*1.0e10 # observation wavelength
	sptime.sensfun = 0.0
	
	printf('A spectrograph on a 30m GSMT which achieves a maximum resolution \n\
	of %6.0f operating with a slit width of at most %5.3f arcsec, operating near \n\
	the maximum practical grating tilt, will require a collimator of focal \n\
        length %5.3f m, and a camera of focal length %5.3f m. The beam diameter \n\
        is %5.3f m. The collimator, grating and camera parameters have been set in \n\
        specpars.\n\n',\
	Rmax, slitmaxsec, fcoll, fcam, fcoll/fnum)

	printf('This assumes a slit of %5.3f arcsec is matched to %4.1f pixels, \n\
	each of	%4.1f microns.\n\n',slitsec, npix, dpix*1.0e06)

	printf('The camera focal ratio is %6.2f. F-ratios smaller than 1.0 will \n\
	be difficult to achieve.\n\n', fcam*fnum/fcoll)

# Telescope
	specpars.telescope = "telescope_GSMT"
	printf('The telescope parameters are set in specpars by the table: %s\n',\
        "telescope_GSMT")

# Detector
	specpars.detector = "HgCdTe"
	printf('The detector parameters are set in specpars by the table: %s\n',\
        "HdCdTe")

	if(s_atm) {

	make_sky(lambdau,R)




# Atmosphere
#	sptime.extinction = "extinct_nearir"
#	sptime.sky = "irsky1_5"
#	printf('The sky absorption and emission tables have been set to the defaults: \n\
#	%s and %s\n',"extinct_nearir","irsky1_5")
#	} else {
#	print('The sky tables have not been changed.\n')
	}


end
